@@ -13,13 +13,9 @@ our @ISA = qw(
 );
 
 our @EXPORT = qw(
-  get_keywords
-  get_resolution
-  get_title
-  get_url
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 use Data::Dumper;
@@ -90,7 +86,7 @@ WWW::YouTube::Info::Simple - simple interface to WWW::YouTube::Info
 
 I guess its pretty much self-explanatory ..
 
-=head1 FUNCTIONS
+=head1 METHODS
 
 =cut
 
@@ -201,14 +197,6 @@ sub get_url {
 
 __END__
 
-=head1 EXPORT
-
-Exported by default:
-get_keywords
-get_resolution
-get_title
-get_url
-
 =head1 SEE ALSO
 
 You might want to have a look at the C<./examples> folder within this distribution,
